@@ -1,16 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2014-2019 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2014-2021 -- leonerd@leonerd.org.uk
 
-package Device::BusPirate::Mode::I2C;
+package Device::BusPirate::Mode::I2C 0.21;
 
-use strict;
+use v5.14;
 use warnings;
 use base qw( Device::BusPirate::Mode );
 
-our $VERSION = '0.20';
-
 use Carp;
 
 use Future::AsyncAwait;
