@@ -1,16 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2020 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2020-2021 -- leonerd@leonerd.org.uk
 
-package Device::BusPirate::Mode::UART;
+package Device::BusPirate::Mode::UART 0.21;
 
-use strict;
+use v5.14;
 use warnings;
 use base qw( Device::BusPirate::Mode );
 
-our $VERSION = '0.20';
-
 use Carp;
 
 use Future::AsyncAwait;
